<?php
/**
 * multipurpose blog functions and definitions
 *
 * @package multipurpose blog
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'multipurpose_blog_setup' ) ) :

/* Theme Setup */
function multipurpose_blog_setup() {

	$GLOBALS['content_width'] = apply_filters( 'multipurpose_blog_content_width', 640 );
	
	load_theme_textdomain( 'multipurpose-blog', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('multipurpose-blog-homepage-thumb',240,145,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'multipurpose-blog' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );
	
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	add_theme_support('responsive-embeds');
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', multipurpose_blog_font_url() ) );

}
endif; // multipurpose_blog_setup
add_action( 'after_setup_theme', 'multipurpose_blog_setup' );

/* Theme Widgets Setup */
function multipurpose_blog_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'multipurpose-blog' ),
		'description'   => __( 'Appears on posts and pages', 'multipurpose-blog' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Posts and Pages Sidebar', 'multipurpose-blog' ),
		'description'   => __( 'Appears on posts and pages', 'multipurpose-blog' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'multipurpose-blog' ),
		'description'   => __( 'Appears on posts and pages', 'multipurpose-blog' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	//Footer widget areas
	$multipurpose_blog_widget_areas = get_theme_mod('footer_widget_areas', '4');
	for ($i=1; $i<=$multipurpose_blog_widget_areas; $i++) {
		register_sidebar( array(
			'name'          => __( 'Footer Widget ', 'multipurpose-blog' ) . $i,
			'id'            => 'footer-' . $i,
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title mb-3 pb-2">',
			'after_title'   => '</h3>',
		) );
	}

}
add_action( 'widgets_init', 'multipurpose_blog_widgets_init' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function multipurpose_blog_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", esc_url( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'multipurpose_blog_pingback_header' );

/* Theme Font URL */
function multipurpose_blog_font_url() {
	$font_url      = '';
	$font_family   = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Roboto:400,700';
	$font_family[] = 'Roboto Condensed:400,700';
	$font_family[] = 'Open Sans';
	$font_family[] = 'Alex Brush';
	$font_family[] = 'Overpass';
	$font_family[] = 'Montserrat:300,400,600,700,800,900';
	$font_family[] = 'Playball:300,400,600,700,800,900';
	$font_family[] = 'Alegreya:300,400,600,700,800,900';
	$font_family[] = 'Julius Sans One';
	$font_family[] = 'Arsenal';
	$font_family[] = 'Slabo';
	$font_family[] = 'Lato';
	$font_family[] = 'Overpass Mono';
	$font_family[] = 'Source Sans Pro';
	$font_family[] = 'Raleway';
	$font_family[] = 'Merriweather';
	$font_family[] = 'Droid Sans';
	$font_family[] = 'Rubik';
	$font_family[] = 'Lora';
	$font_family[] = 'Ubuntu';
	$font_family[] = 'Cabin';
	$font_family[] = 'Arimo';
	$font_family[] = 'Playfair Display';
	$font_family[] = 'Quicksand';
	$font_family[] = 'Padauk';
	$font_family[] = 'Muli';
	$font_family[] = 'Inconsolata';
	$font_family[] = 'Bitter';
	$font_family[] = 'Pacifico';
	$font_family[] = 'Indie Flower';
	$font_family[] = 'VT323';
	$font_family[] = 'Dosis';
	$font_family[] = 'Frank Ruhl Libre';
	$font_family[] = 'Fjalla One';
	$font_family[] = 'Oxygen';
	$font_family[] = 'Arvo';
	$font_family[] = 'Noto Serif';
	$font_family[] = 'Lobster';
	$font_family[] = 'Crimson Text';
	$font_family[] = 'Yanone Kaffeesatz';
	$font_family[] = 'Anton';
	$font_family[] = 'Libre Baskerville';
	$font_family[] = 'Bree Serif';
	$font_family[] = 'Gloria Hallelujah';
	$font_family[] = 'Josefin Sans';
	$font_family[] = 'Abril Fatface';
	$font_family[] = 'Varela Round';
	$font_family[] = 'Vampiro One';
	$font_family[] = 'Shadows Into Light';
	$font_family[] = 'Cuprum';
	$font_family[] = 'Rokkitt';
	$font_family[] = 'Vollkorn';
	$font_family[] = 'Francois One';
	$font_family[] = 'Orbitron';
	$font_family[] = 'Patua One';
	$font_family[] = 'Acme';
	$font_family[] = 'Satisfy';
	$font_family[] = 'Josefin Slab';
	$font_family[] = 'Quattrocento Sans';
	$font_family[] = 'Architects Daughter';
	$font_family[] = 'Russo One';
	$font_family[] = 'Monda';
	$font_family[] = 'Righteous';
	$font_family[] = 'Lobster Two';
	$font_family[] = 'Hammersmith One';
	$font_family[] = 'Courgette';
	$font_family[] = 'Permanent Marker';
	$font_family[] = 'Cherry Swash';
	$font_family[] = 'Cormorant Garamond';
	$font_family[] = 'Poiret One';
	$font_family[] = 'BenchNine';
	$font_family[] = 'Economica';
	$font_family[] = 'Handlee';
	$font_family[] = 'Cardo';
	$font_family[] = 'Alfa Slab One';
	$font_family[] = 'Averia Serif Libre';
	$font_family[] = 'Cookie';
	$font_family[] = 'Chewy';
	$font_family[] = 'Great Vibes';
	$font_family[] = 'Coming Soon';
	$font_family[] = 'Philosopher';
	$font_family[] = 'Days One';
	$font_family[] = 'Kanit';
	$font_family[] = 'Shrikhand';
	$font_family[] = 'Tangerine';
	$font_family[] = 'IM Fell English SC';
	$font_family[] = 'Boogaloo';
	$font_family[] = 'Bangers';
	$font_family[] = 'Fredoka One';
	$font_family[] = 'Bad Script';
	$font_family[] = 'Volkhov';
	$font_family[] = 'Shadows Into Light Two';
	$font_family[] = 'Marck Script';
	$font_family[] = 'Sacramento';
	$font_family[] = 'Unica One';
	$font_family[] = 'Dancing Script:400,700';
	
	$query_args = array(
		'family' => rawurlencode(implode('|', $font_family)),
	);
	$font_url = add_query_arg($query_args, '//fonts.googleapis.com/css');
	return $font_url;
}

function multipurpose_blog_sanitize_dropdown_pages( $page_id, $setting ) {
  // Ensure $input is an absolute integer.
  $page_id = absint( $page_id );
  // If $page_id is an ID of a published page, return it; otherwise, return the default.
  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'multipurpose_blog_per_columns');
if (!function_exists('multipurpose_blog_per_columns')) {
	function multipurpose_blog_per_columns() {
		$columns = get_theme_mod( 'multipurpose_blog_per_columns', 3 );
		return $columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'multipurpose_blog_shop_per_page', 20 );
function multipurpose_blog_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'multipurpose_blog_shop_per_page', 9 );
	return $cols;
}

/*radio button sanitization*/
 function multipurpose_blog_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function multipurpose_blog_sanitize_phone_number( $phone ) {
	return preg_replace( '/[^\d+]/', '', $phone );
}

function multipurpose_blog_sanitize_select( $input, $setting ) {
	// Ensure input is a slug.
	$input = sanitize_key( $input );

	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

function multipurpose_blog_sanitize_checkbox( $input ) {
	// Boolean check 
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

// Excerpt Limit Begin
function multipurpose_blog_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

/* Theme enqueue scripts */
function multipurpose_blog_scripts() {
	wp_enqueue_style( 'multipurpose-blog-font', multipurpose_blog_font_url(), array() );
	
	// blocks-css
	wp_enqueue_style( 'multipurpose-blog-block-style', get_theme_file_uri('/css/blocks.css') );

	wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri()) . '/css/bootstrap.css');
	wp_enqueue_style( 'multipurpose-blog-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'multipurpose-blog-style', 'rtl', 'replace' );
	wp_enqueue_style( 'font-awesome-css', esc_url(get_template_directory_uri()).'/css/fontawesome-all.css' );

	// Paragraph
	$multipurpose_blog_paragraph_color       = get_theme_mod('multipurpose_blog_paragraph_color', '');
	$multipurpose_blog_paragraph_font_family = get_theme_mod('multipurpose_blog_paragraph_font_family', '');
	$multipurpose_blog_paragraph_font_size   = get_theme_mod('multipurpose_blog_paragraph_font_size', '');
	// "a" tag
	$multipurpose_blog_atag_color       = get_theme_mod('multipurpose_blog_atag_color', '');
	$multipurpose_blog_atag_font_family = get_theme_mod('multipurpose_blog_atag_font_family', '');
	// "li" tag
	$multipurpose_blog_li_color       = get_theme_mod('multipurpose_blog_li_color', '');
	$multipurpose_blog_li_font_family = get_theme_mod('multipurpose_blog_li_font_family', '');
	
	// H1
	$multipurpose_blog_h1_color       = get_theme_mod('multipurpose_blog_h1_color', '');
	$multipurpose_blog_h1_font_family = get_theme_mod('multipurpose_blog_h1_font_family', '');
	$multipurpose_blog_h1_font_size   = get_theme_mod('multipurpose_blog_h1_font_size', '');
	// H2
	$multipurpose_blog_h2_color       = get_theme_mod('multipurpose_blog_h2_color', '');
	$multipurpose_blog_h2_font_family = get_theme_mod('multipurpose_blog_h2_font_family', '');
	$multipurpose_blog_h2_font_size   = get_theme_mod('multipurpose_blog_h2_font_size', '');
	// H3
	$multipurpose_blog_h3_color       = get_theme_mod('multipurpose_blog_h3_color', '');
	$multipurpose_blog_h3_font_family = get_theme_mod('multipurpose_blog_h3_font_family', '');
	$multipurpose_blog_h3_font_size   = get_theme_mod('multipurpose_blog_h3_font_size', '');
	// H4
	$multipurpose_blog_h4_color       = get_theme_mod('multipurpose_blog_h4_color', '');
	$multipurpose_blog_h4_font_family = get_theme_mod('multipurpose_blog_h4_font_family', '');
	$multipurpose_blog_h4_font_size   = get_theme_mod('multipurpose_blog_h4_font_size', '');
	// H5
	$multipurpose_blog_h5_color       = get_theme_mod('multipurpose_blog_h5_color', '');
	$multipurpose_blog_h5_font_family = get_theme_mod('multipurpose_blog_h5_font_family', '');
	$multipurpose_blog_h5_font_size   = get_theme_mod('multipurpose_blog_h5_font_size', '');
	// H6
	$multipurpose_blog_h6_color       = get_theme_mod('multipurpose_blog_h6_color', '');
	$multipurpose_blog_h6_font_family = get_theme_mod('multipurpose_blog_h6_font_family', '');
	$multipurpose_blog_h6_font_size   = get_theme_mod('multipurpose_blog_h6_font_size', '');

	$multipurpose_blog_custom_css = '
		p,span{
		    color:'.esc_html($multipurpose_blog_paragraph_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_paragraph_font_family).';
		    font-size: '.esc_html($multipurpose_blog_paragraph_font_size).';
		}
		a{
		    color:'.esc_html($multipurpose_blog_atag_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_atag_font_family).';
		}
		li{
		    color:'.esc_html($multipurpose_blog_li_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_li_font_family).';
		}
		h1{
		    color:'.esc_html($multipurpose_blog_h1_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_h1_font_family).'!important;
		    font-size: '.esc_html($multipurpose_blog_h1_font_size).'!important;
		}
		h2{
		    color:'.esc_html($multipurpose_blog_h2_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_h2_font_family).'!important;
		    font-size: '.esc_html($multipurpose_blog_h2_font_size).'!important;
		}
		h3{
		    color:'.esc_html($multipurpose_blog_h3_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_h3_font_family).'!important;
		    font-size: '.esc_html($multipurpose_blog_h3_font_size).'!important;
		}
		h4{
		    color:'.esc_html($multipurpose_blog_h4_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_h4_font_family).'!important;
		    font-size: '.esc_html($multipurpose_blog_h4_font_size).'!important;
		}
		h5{
		    color:'.esc_html($multipurpose_blog_h5_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_h5_font_family).'!important;
		    font-size: '.esc_html($multipurpose_blog_h5_font_size).'!important;
		}
		h6{
		    color:'.esc_html($multipurpose_blog_h6_color).'!important;
		    font-family: '.esc_html($multipurpose_blog_h6_font_family).'!important;
		    font-size: '.esc_html($multipurpose_blog_h6_font_size).'!important;
		}
	';
	wp_add_inline_style('multipurpose-blog-basic-style', $multipurpose_blog_custom_css);

	/* Theme Color sheet */
	require get_parent_theme_file_path( '/theme-color-option.php' );
	wp_add_inline_style( 'multipurpose-blog-basic-style',$multipurpose_blog_custom_css );
	wp_enqueue_script( 'tether-js', esc_url(get_template_directory_uri()) . '/js/tether.js', array('jquery') ,'',true);
	wp_enqueue_script( 'bootstrap-js', esc_url(get_template_directory_uri()) . '/js/bootstrap.js', array('jquery') ,'',true);
	wp_enqueue_script( 'jquery-superfish', esc_url(get_template_directory_uri()) . '/js/jquery.superfish.js', array('jquery') ,'',true);
	wp_enqueue_script( 'multipurpose-blog-customscripts', esc_url(get_template_directory_uri()) . '/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'multipurpose_blog_scripts' );

define('MULTIPURPOSE_BLOG_LIVE_DEMO',__('https://www.buywptemplates.com/multipurpose-blog-wordpress-theme/', 'multipurpose-blog'));
define('MULTIPURPOSE_BLOG_BUY_PRO',__('https://www.buywptemplates.com/themes/multipurpose-blog-wordpress-theme/', 'multipurpose-blog'));
define('MULTIPURPOSE_BLOG_PRO_DOC',__('https://www.buywptemplates.com/demo/docs/multipurpose-blog-pro/', 'multipurpose-blog'));
define('MULTIPURPOSE_BLOG_FREE_DOC',__('https://buywptemplates.com/demo/docs/free-multipurpose-blog/', 'multipurpose-blog'));
define('MULTIPURPOSE_BLOG_PRO_SUPPORT',__('https://www.buywptemplates.com/support/', 'multipurpose-blog'));
define('MULTIPURPOSE_BLOG_FREE_SUPPORT',__('https://wordpress.org/support/theme/multipurpose-blog/', 'multipurpose-blog'));
define('MULTIPURPOSE_BLOG_CREDIT',__('https://www.buywptemplates.com/themes/wp-multipurpose-blog-wordpress-theme/', 'multipurpose-blog'));

if ( ! function_exists( 'multipurpose_blog_credit' ) ) {
	function multipurpose_blog_credit(){
		echo "<a href=".esc_url(MULTIPURPOSE_BLOG_CREDIT).">".esc_html__('Blog WordPress Theme','multipurpose-blog')."</a>";
	}
}

/**
* Switch sanitization
*/
if ( ! function_exists( 'multipurpose_blog_switch_sanitization' ) ) {
	function multipurpose_blog_switch_sanitization( $input ) {
		if ( true === $input ) {
			return 1;
		} else {
			return 0;
		}
	}
}

/**
 * Integer sanitization
 */
if ( ! function_exists( 'multipurpose_blog_sanitize_integer' ) ) {
	function multipurpose_blog_sanitize_integer( $input ) {
		return (int) $input;
	}
}

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Load customizer file. */
require get_template_directory() . '/inc/customizer.php';

/** Load welcome message.*/
require get_template_directory() . '/inc/dashboard/get_started_info.php';